@@ -7,7 +7,7 @@ describe("make_step", {
 
     # Act, Assert
     expect_error(
-      make_step("Given")("the Maker has the word '{string}'", implementation),
+      make_step("Given")("the Maker has the word {string}", implementation),
       regexp = "context",
       fixed = TRUE
     )
